@@ -1,13 +1,15 @@
 """ A collection of widgets based off of ImGui.
 
-By convention, all widgets take a string identifier as the first parameter, and return the `(identifier, value)` pair.
-This is done for convenience, as Python syntax for mapping values is a bit busy.
+By convention, most widgets take a string identifier as the first parameter, and return the `(identifier, value)` pair.
+This is done for convenience, as Python syntax for mapping values is a bit busy. If you want to return a different
+identifier to what is displayed on screen, use the `tag` keyword argument which is available for all widgets where
+it makes sense.
 
 Most widgets are just thin wrappers over [widgets in PyImGui](https://pyimgui.readthedocs.io/en/latest/reference/imgui.core.html).
 If any widget from ImGui is not listed here, it is mostly trivial to add it. New widgets can be created by writing
 generators by hand, or by using helper functions `concur.core.interactive_elem` or `concur.core.lift`.
 
-Some widgets (`transform`, `key_pressed`, etc.) don't do any drawing and serve purely for control flow, or user interaction.
+Some widgets (`transform`, `key_press`, etc.) don't do any drawing and serve purely for control flow, or user interaction.
 
 All of the functions in this module are re-exported in the root module for convenience.
 """
@@ -43,7 +45,7 @@ def window(title: str,
            flags: int = 0) -> Widget:
     """ Create a window with a given `widget` inside.
 
-    Window title must be unique. Contents are drawn only if the window is opened.
+    Contents are drawn only if the window is opened. Window title must be unique. Windows must not be nested.
     """
     while True:
         if position is not None:
@@ -64,7 +66,24 @@ def window(title: str,
 
 
 def child(name, widget, width, height, border=False, flags=0):
-    """ Create a sized box with a `widget` inside a window. """
+    r""" Create a sized box with a `widget` inside.
+
+    If the contents overflow, scrollbars will be created by default.
+    Sizing of the child widget allows for three modes, depending on the sign of parameters `width` and `height`:
+
+    * ==0 - use the remaining window size
+    * \>0 - fixed size in pixels
+    * <0 - use remaining window size minus abs(size) in pixels
+
+    Args:
+        name: Child name. This has no effect, and will be removed in the future.
+        widget: Widget to display inside the box.
+        width: Box width.
+        height: Box height.
+        border: Toggle border visibility.
+        flags: Advanced customization flags. See the
+            [list of available flags](https://pyimgui.readthedocs.io/en/latest/guide/window-flags.html#window-flag-options).
+    """
     while True:
         imgui.begin_child(name, width, height, border, flags)
         try:
